@@ -221,7 +221,7 @@ class PyBambooHR(object):
         """
         get_fields = []
 
-        field_list = [underscore_to_camelcase(field) for field in field_list]
+        field_list = [underscore_to_camelcase(field) for field in field_list] if field_list else None
 
         if field_list:
             for f in field_list:
